@@ -23,7 +23,7 @@
 
 namespace Analitza {
 class Expression;
-};
+}
 
 
 /**
@@ -48,7 +48,7 @@ class Expression;
 class VectorCommand: public Analitza::FunctionDefinition
 {
 public:
-    virtual Analitza::Expression operator()(const QList< Analitza::Expression >& args);
+    virtual Analitza::Expression operator()(const QList< Analitza::Expression >& args) override;
     
     static const QString id;
     static const Analitza::ExpressionType type;
