@@ -120,7 +120,9 @@ void Plotter3DES::initGL()
     );
     program.link();
 
-    updatePlots(QModelIndex(), 0, m_model->rowCount()-1);
+    if (m_model && m_model->rowCount() > 0) {
+        updatePlots(QModelIndex(), 0, m_model->rowCount()-1);
+    }
 }
 
 void Plotter3DES::resetViewport()
